# mypy-boto3-glue

[![PyPI - mypy-boto3-glue](https://img.shields.io/pypi/v/mypy-boto3-glue.svg?color=blue)](https://pypi.org/project/mypy-boto3-glue)
[![PyPI - Python Version](https://img.shields.io/pypi/pyversions/mypy-boto3-glue.svg?color=blue)](https://pypi.org/project/mypy-boto3-glue)
[![Docs](https://img.shields.io/readthedocs/mypy-boto3-builder.svg?color=blue)](https://mypy-boto3-builder.readthedocs.io/)

- [mypy-boto3-glue](#mypy-boto3-glue)
  - [How to use](#how-to-use)
  - [Automated type discovery](#automated-type-discovery)


Type annotations for
[boto3.Glue 1.13.24](https://boto3.amazonaws.com/v1/documentation/api/1.13.24/reference/services/glue.html#Glue) service
compatible with [mypy](https://github.com/python/mypy), [VSCode](https://code.visualstudio.com/),
[PyCharm](https://www.jetbrains.com/pycharm/) and other tools.

Generated by [mypy-boto3-buider 2.0.2](https://github.com/vemel/mypy_boto3_builder).

More information can be found on [boto3-stubs](https://pypi.org/project/boto3-stubs/) page.

- [mypy-boto3-glue](#mypy-boto3-glue)
  - [How to use](#how-to-use)
    - [Type checking](#type-checking)
  - [How it works](#how-it-works)

## How to use

Make sure you have [mypy](https://github.com/python/mypy) installed and activated in your IDE.

Install `boto3-stubs` for `Glue` service.

```bash
python -m pip install boto3-stubs[glue]

# update installed packages index for automated type discovery
python -m mypy_boto3
```

Use `boto3` with `mypy_boto3_glue` in your project and enjoy type checking and auto-complete.

```python
import boto3

from mypy_boto3_glue import GlueClient

# Now mypy can check if your code is valid.
client: GlueClient = boto3.client("glue")

# works for session as well
session = boto3.session.Session(region="us-west-1")
session_client: GlueClient = session.client("glue")



# Annotated paginators are included as well

import mypy_boto3_glue.paginator as glue_paginators

get_classifiers_paginator: glue_paginators.GetClassifiersPaginator = client.get_paginator("get_classifiers")
get_connections_paginator: glue_paginators.GetConnectionsPaginator = client.get_paginator("get_connections")
get_crawler_metrics_paginator: glue_paginators.GetCrawlerMetricsPaginator = client.get_paginator("get_crawler_metrics")
get_crawlers_paginator: glue_paginators.GetCrawlersPaginator = client.get_paginator("get_crawlers")
get_databases_paginator: glue_paginators.GetDatabasesPaginator = client.get_paginator("get_databases")
get_dev_endpoints_paginator: glue_paginators.GetDevEndpointsPaginator = client.get_paginator("get_dev_endpoints")
get_job_runs_paginator: glue_paginators.GetJobRunsPaginator = client.get_paginator("get_job_runs")
get_jobs_paginator: glue_paginators.GetJobsPaginator = client.get_paginator("get_jobs")
get_partitions_paginator: glue_paginators.GetPartitionsPaginator = client.get_paginator("get_partitions")
get_security_configurations_paginator: glue_paginators.GetSecurityConfigurationsPaginator = client.get_paginator("get_security_configurations")
get_table_versions_paginator: glue_paginators.GetTableVersionsPaginator = client.get_paginator("get_table_versions")
get_tables_paginator: glue_paginators.GetTablesPaginator = client.get_paginator("get_tables")
get_triggers_paginator: glue_paginators.GetTriggersPaginator = client.get_paginator("get_triggers")
get_user_defined_functions_paginator: glue_paginators.GetUserDefinedFunctionsPaginator = client.get_paginator("get_user_defined_functions")
```

## Automated type discovery

`mypy_boto3` package can generate index for `mypy_boto3_glue` and other installed services.

```bash
# Run this command when you add or remove service packages
python -m mypy_boto3
```

Generated index provides overloads for `boto3.client` and `boto3.service`,
`boto3.Session.client` and `boto3.Session.resource` functions,
so explicit type annotations are not needed.

- `mypy` supports function overloads as expected
- `PyCharm` also supports function overloads, but consumes a lot of RAM, use carefully
- `VSCode` does not currently support function overloads

Also, generated index allows you to import types from `mypy_boto3`:

```python
# you can replace imports
import mypy_boto3_glue as glue
from mypy_boto3_glue import GlueClient

# with these
from mypy_boto3 import glue
from mypy_boto3.glue import GlueClient
```